@@ -104,7 +104,7 @@ class BaseNet(pl.LightningModule):
             else:
                 criterion = MSELoss()
         else:
-            criterion = CELossMetrics() if self.n_classes > 2 else BCELossMetrics()
+            criterion = CELossMetrics(self.n_classes) if self.n_classes > 2 else BCELossMetrics()
         return criterion
 
     def training_step(self, train_batch, batch_idx):
@@ -290,7 +290,7 @@ class ConvNet(pl.LightningModule):
             if self.model_type == "UNet":
                 criterion = CEDiceLossMetrics(self.n_classes)
             else:
-                criterion = CELossMetrics() if self.n_classes > 2 else BCELossMetrics()
+                criterion = CELossMetrics(self.n_classes) if self.n_classes > 2 else BCELossMetrics()
         return criterion
 
     @staticmethod
