@@ -39,13 +39,13 @@ def split_data(
         X_train, y_train = X, y
 
     if not isinstance(X_train, torch.Tensor):
-        X_predict_tensor = torch.Tensor(X_train)
+        X_predict_tensor = torch.Tensor(X_train).float()
     if not isinstance(y_train, torch.Tensor):
-        y_predict_tensor = torch.Tensor(y_train)
+        y_predict_tensor = torch.Tensor(y_train).float()
     if not isinstance(X_test, torch.Tensor):
-        X_test_tensor = torch.Tensor(X_test)
+        X_test_tensor = torch.Tensor(X_test).float()
     if not isinstance(y_test, torch.Tensor):
-        y_test_tensor = torch.Tensor(y_test)
+        y_test_tensor = torch.Tensor(y_test).float()
 
    
     X_train, X_val, y_train, y_val = train_test_split(
@@ -56,13 +56,13 @@ def split_data(
     )
     
     if not isinstance(X_train, torch.Tensor):
-        X_train_tensor = torch.Tensor(X_train)
+        X_train_tensor = torch.Tensor(X_train).float()
     if not isinstance(y_train, torch.Tensor):
-        y_train_tensor = torch.Tensor(y_train)
+        y_train_tensor = torch.Tensor(y_train).float()
     if not isinstance(X_val, torch.Tensor):
-        X_val_tensor = torch.Tensor(X_val)
+        X_val_tensor = torch.Tensor(X_val).float()
     if not isinstance(y_val, torch.Tensor):
-        y_val_tensor = torch.Tensor(y_val)
+        y_val_tensor = torch.Tensor(y_val).float()
 
     return X_train_tensor, y_train_tensor, X_val_tensor, y_val_tensor, X_predict_tensor, y_predict_tensor, X_test_tensor, y_test_tensor 
 
@@ -102,18 +102,16 @@ class DataModule(pl.LightningDataModule):
 
     def setup(self, stage):
         if self.X_val is not None and self.y_val is not None and self.X_test is not None and self.y_test is not None:
-            self.X_train_tensor = torch.Tensor(self.X)
-            self.X_val_tensor = torch.Tensor(self.X_val)
-            self.X_test_tensor = torch.Tensor(self.X_test)
-            self.y_train_tensor = torch.Tensor(self.y)
-            self.y_val_tensor = torch.Tensor(self.y_val)
-            self.y_test_tensor = torch.Tensor(self.y_test)
-            self.X_predict_tensor = torch.Tensor(np.concatenate([self.X, self.X_val]))
-            self.y_predict_tensor = torch.Tensor(np.concatenate([self.y, self.y_val]))
+            self.X_train_tensor = torch.Tensor(self.X).float()
+            self.X_val_tensor = torch.Tensor(self.X_val).float()
+            self.X_test_tensor = torch.Tensor(self.X_test).float()
+            self.y_train_tensor = torch.Tensor(self.y).float()
+            self.y_val_tensor = torch.Tensor(self.y_val).float()
+            self.y_test_tensor = torch.Tensor(self.y_test).float()
+            self.X_predict_tensor = torch.Tensor(np.concatenate([self.X, self.X_val])).float()
+            self.y_predict_tensor = torch.Tensor(np.concatenate([self.y, self.y_val])).float()
         else:
-            self.X_train_tensor, self.y_train_tensor, self.X_val_tensor, self.y_val_tensor, \
-                self.X_predict_tensor, self.y_predict_tensor, self.X_test_tensor, self.y_test_tensor = \
-            split_data(
+            self.X_train_tensor, self.y_train_tensor, self.X_val_tensor, self.y_val_tensor, self.X_predict_tensor, self.y_predict_tensor, self.X_test_tensor, self.y_test_tensor = split_data(
                 X=self.X, 
                 y=self.y,
                 X_test=self.X_test,
